@@ -37,7 +37,6 @@
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -45,7 +44,6 @@
 #include "timidity_internal.h"
 #include "common.h"
 #include "instrum.h"
-#include "instrum_dls.h"
 #include "resample.h"
 #include "tables.h"
 
@@ -176,38 +174,43 @@ static void load_instrument(MidSong *song, const char *name,
 				   int strip_loop, int strip_envelope,
 				   int strip_tail)
 {
+#if (TIM_MAXPATH < 256)
+#define TMPSIZE 256
+#else
+#define TMPSIZE TIM_MAXPATH
+#endif
   MidInstrument *ip;
   MidSample *sp;
   FILE *fp;
-  char tmp[TIM_MAXPATH];
+  char tmp[TMPSIZE];
   int i,j;
   static const char *patch_ext[] = PATCH_EXT_LIST;
 
+  TIMI_UNUSED(percussion);
   *out = NULL;
   if (!name) return;
 
   /* Open patch file */
-  if ((song->ifp=timi_openfile(name)) == NULL)
+  if ((fp=timi_openfile(name)) == NULL)
     {
       /* Try with various extensions */
       for (i=0; patch_ext[i]; i++)
 	{
-	  if (strlen(name)+strlen(patch_ext[i])<TIM_MAXPATH)
+	  if (strlen(name)+strlen(patch_ext[i])<sizeof(tmp))
 	    {
 	      strcpy(tmp, name);
 	      strcat(tmp, patch_ext[i]);
-	      if ((song->ifp=timi_openfile(tmp)) != NULL)
+	      if ((fp=timi_openfile(tmp)) != NULL)
 		break;
 	    }
 	}
     }
 
-  if (song->ifp == NULL)
+  if (fp == NULL)
     {
       DEBUG_MSG("Instrument `%s' can't be found.\n", name);
       return;
     }
-  fp = song->ifp;
 
   DEBUG_MSG("Loading instrument %s\n", tmp);
 
@@ -251,15 +254,15 @@ static void load_instrument(MidSong *song, const char *name,
       uint16 tmpshort;
       uint8 tmpchar;
 
-#define READ_CHAR(thing)				\
-      if (1 != fread(&tmpchar, 1, 1, fp)) goto badread;	\
-      thing = tmpchar;
-#define READ_SHORT(thing)				\
-      if (1 != fread(&tmpshort, 2, 1, fp)) goto badread;\
-      thing = SWAPLE16(tmpshort);
-#define READ_LONG(thing)				\
-      if (1 != fread(&tmplong, 4, 1, fp)) goto badread;	\
-      thing = SWAPLE32(tmplong);
+#define READ_CHAR(thing)					\
+  if (1 != fread(&tmpchar, 1, 1, fp))  goto badread;		\
+  thing = tmpchar;
+#define READ_SHORT(thing)					\
+  if (1 != fread(&tmpshort, 2, 1, fp)) goto badread;		\
+  thing = SWAPLE16(tmpshort);
+#define READ_LONG(thing)					\
+  if (1 != fread(&tmplong, 4, 1, fp))  goto badread;		\
+  thing = SWAPLE32(tmplong);
 
       fseek(fp, 7, SEEK_CUR); /* Skip the wave name */
 
@@ -275,10 +278,6 @@ static void load_instrument(MidSong *song, const char *name,
       READ_LONG(sp->low_freq);
       READ_LONG(sp->high_freq);
       READ_LONG(sp->root_freq);
-#if defined(TIMIDITY_USE_DLS)
-      sp->low_vel = 0;
-      sp->high_vel = 127;
-#endif /* USE_DLS */
       fseek(fp, 2, SEEK_CUR); /* Why have a "root frequency" and then
 				* "tuning"?? */
 
@@ -525,7 +524,6 @@ static void load_instrument(MidSong *song, const char *name,
     }
 
   fclose(fp);
-  song->ifp = NULL;
   return;
 
 nomem:
@@ -537,7 +535,6 @@ fail:
   free_instrument (ip);
 badpat:
   fclose(fp);
-  song->ifp = NULL;
   *out = NULL;
 }
 
@@ -555,13 +552,6 @@ static int fill_bank(MidSong *song, int dr, int b)
     {
       if (bank->instrument[i]==MAGIC_LOAD_INSTRUMENT)
 	{
-#if defined(TIMIDITY_USE_DLS)
-	  load_instrument_dls(song, &bank->instrument[i], dr, b, i);
-	  if (bank->instrument[i])
-	    {
-	      continue;
-	    }
-#endif /* TIMIDITY_USE_DLS */
 	  if (!(bank->tone[i].name))
 	    {
 	      DEBUG_MSG("No instrument mapped to %s %d, program %d%s\n",
